import 'package:http/http.dart';
import 'dart:io';
import 'dart:async';

class ConnectionUtils {
  static Future<Response> options(String url) async {
    final client = Client();
    final request = Request('OPTIONS', Uri.parse(url));
    final streamedResponse = await client.send(request);
    return Response.fromStream(streamedResponse);
  }

  static Future<bool> isResponseSuccessful(String url,
      {Duration? timeout, int? timeoutMillis}) async {
    final future = options(url);
    if (timeoutMillis != null) timeout = Duration(milliseconds: timeoutMillis);
    final response = await (timeout == null
        ? future
        : future.timeout(timeout,
            onTimeout: () => Response('', HttpStatus.requestTimeout)));
    return response.statusCode >= 200 || response.statusCode < 300;
  }

  static Future<bool> isResponseOnline(String url,
      {Duration? timeout, int? timeoutMillis}) async {
    final future = options(url);
    if (timeoutMillis != null) timeout = Duration(milliseconds: timeoutMillis);
    final response = await (timeout == null
        ? future
        : future.timeout(timeout,
            onTimeout: () => Response('', HttpStatus.requestTimeout)));
    switch (response.statusCode) {
      case HttpStatus.notFound:
      case HttpStatus.requestTimeout:
      case HttpStatus.gatewayTimeout:
      case HttpStatus.networkConnectTimeoutError:
        return false;
    }
    return true;
  }
}
